gedidb.GEDIProvider
===================

.. currentmodule:: gedidb

.. autoclass:: GEDIProvider

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~GEDIProvider.__init__
      ~GEDIProvider.get_available_variables
      ~GEDIProvider.get_data
      ~GEDIProvider.query_data
      ~GEDIProvider.query_nearest_shots
      ~GEDIProvider.to_dataframe
      ~GEDIProvider.to_xarray
   
   

   
   
   